mailr13410 - /branches/gui_testing/gui/components/spin_view.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on July 01, 2011 - 22:51:
Author: bugman
Date: Fri Jul  1 22:51:20 2011
New Revision: 13410

URL: http://svn.gna.org/viewcvs/relax?rev=13410&view=rev
Log:
The spin viewer now updates and shows nothing if all data has been deleted 
from relax.


Modified:
    branches/gui_testing/gui/components/spin_view.py

Modified: branches/gui_testing/gui/components/spin_view.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/gui_testing/gui/components/spin_view.py?rev=13410&r1=13409&r2=13410&view=diff
==============================================================================
--- branches/gui_testing/gui/components/spin_view.py (original)
+++ branches/gui_testing/gui/components/spin_view.py Fri Jul  1 22:51:20 2011
@@ -866,8 +866,9 @@
         else:
             pipe = get_pipe(pipe_name)
 
         # No data pipe, so do nothing.
         if not pipe:
+            self.tree.DeleteChildren(self.root)
             return
 
         # Update the molecules.
@@ -866,8 +866,9 @@
             pipe = get_pipe(pipe_name)
 
-        # No data pipe, so do nothing.
+        # No data pipe, so delete everything and return.
         if not pipe:




Related Messages


Powered by MHonArc, Updated Mon Jul 04 01:20:02 2011